@@ -122,7 +122,7 @@ def _deploy(test):
 
     _validate_base_directory()
     # Check and make output dir
-    outdir = Path.cwd() + "/.idk.out"
+    outdir = Path.cwd() / ".idk.out"
     if not os.path.exists(outdir):
         os.mkdir(outdir)
 
